pub struct CompatNetwork<A, TYPES: NodeType> {
cliquenet: Cliquenet<TYPES::SignatureKey>,
fallback: A,
use_cliquenet: Arc<AtomicBool>,
upgrade_lock: Arc<OnceLock<UpgradeLock<TYPES>>>,
}Expand description
Compatibility network.
Uses either a fallback network (any impl of ConnectedNetwork), or else
Cliquenet once the protocol has been upgraded to CLIQUENET_VERSION.
Receiving listens on both networks simultaneously so that messages arriving on either side are never lost. Sending is routed to the active network only.
Fields
cliquenet: Cliquenet<TYPES::SignatureKey>fallback: Ause_cliquenet: Arc<AtomicBool>upgrade_lock: Arc<OnceLock<UpgradeLock<TYPES>>>Implementations
Sourceimpl<A, TYPES> CompatNetwork<A, TYPES>where
TYPES: NodeType,
impl<A, TYPES> CompatNetwork<A, TYPES>where
TYPES: NodeType,
pub async fn new(cliquenet: Cliquenet<TYPES::SignatureKey>, fallback: A) -> Self
pub fn cliquenet(&self) -> &Cliquenet<TYPES::SignatureKey>
pub fn fallback(&self) -> &A
pub fn set_upgrade_lock(&self, lock: UpgradeLock<TYPES>)
pub fn use_cliquenet(&self)
pub fn is_cliquenet(&self) -> bool
fn maybe_switch_to_cliquenet(&self, view: ViewNumber)